@@ -8,7 +8,6 @@ import httpx
 import openai
 import openai.types as openai_types
 import openai.types.chat as openai_chat_types
-from openai.types.chat import ChatCompletionStreamOptionsParam
 
 import maitai
 from maitai._config import config
@@ -266,8 +265,6 @@ class Completions:
             presence_penalty = maitai_config.presence_penalty
         if timeout == openai.NOT_GIVEN and maitai_config.timeout > 0:
             timeout = maitai_config.timeout
-        if stream_options == openai.NOT_GIVEN and stream:
-            stream_options = ChatCompletionStreamOptionsParam(include_usage=True)
         if context_retrieval_enabled is None:
             context_retrieval_enabled = maitai_config.context_retrieval_enabled
         if fallback_model is None and maitai_config.fallback_model:
@@ -331,7 +328,15 @@ class Completions:
                     retry_args["model"] = model
                     retry_args["fallback_model"] = fallback_model
                     return _process_inference_stream(
-                        response, retry_args, self.create, timing
+                        response,
+                        retry_args,
+                        self.create,
+                        timing,
+                        includes_usage=(
+                            stream_options.get("include_usage", False)
+                            if stream_options and stream_options != openai.NOT_GIVEN
+                            else False
+                        ),
                     )
                 # ChatCompletion only
                 for resp in response:
@@ -506,6 +511,7 @@ def _process_inference_stream(
     retry_args: dict,
     retry_func,
     timing: RequestTimingMetric,
+    includes_usage: bool = False,
 ) -> Iterable[MaitaiChunk]:
     first = True
     try:
@@ -526,6 +532,12 @@ def _process_inference_stream(
                     maitai.Inference.store_request_timing_data(timing)
                 if chunk.usage:
                     return
+                if (
+                    not includes_usage
+                    and chunk.choices
+                    and chunk.choices[0].finish_reason
+                ):
+                    return
     except MaitaiConnectionError as e:
         if "gpt" not in retry_args.get("model", "") and "gpt" in retry_args.get(
             "fallback_model", ""
