@@ -13,7 +13,5 @@ def openai_messages_to_proto(messages: Iterable[ChatCompletionMessageParam]):
         elif isinstance(message, ChatCompletionMessage):
             proto_messages.append(ChatMessage().from_pydict(message.to_pydict()))
         else:
-            proto_messages.append(
-                ChatMessage().from_pydict(message)
-            )
+            proto_messages.append(ChatMessage().from_pydict(message))
     return proto_messages
